@@ -87,7 +87,7 @@ def find_related(node_type: SchemaType, id: str, related_type: SchemaType, limit
                       limit=limit, offset=offset, relationship=relationship)
     response = _safe_get_request(url)
     # handle errors
-    return None if type(response) == dict else response
+    return response.get('results', []) if type(response) == dict else response
 
 
 def download_hestia(node_id: str, node_type=SchemaType.TERM, data_state='', mode='') -> dict:
@@ -232,3 +232,36 @@ def find_node_exact(node_type: SchemaType, args: dict) -> dict:
     results = search(query={'bool': {'must': must}}, limit=2)
     # do not return a duplicate
     return results[0] if len(results) == 1 else None
+
+
+# should support up to 65,000 terms, but limit to 1000 just in case
+# https://www.elastic.co/guide/en/elasticsearch/reference/current/query-dsl-terms-query.html#terms-top-level-params
+def find_term_ids_by_names(names, batch_size=1000):
+    unique_names_set = set(names)
+    unique_names = list(unique_names_set)
+    unique_names_count = len(unique_names)
+    result = {}
+    for i in range(0, unique_names_count, batch_size):
+        query = {
+            "constant_score": {
+                "filter": {
+                    "bool": {
+                        "must": [
+                            {
+                                "terms": {
+                                    "name.keyword": unique_names[i: i + batch_size],
+                                }
+                            },
+                            {"term": {"@type.keyword": "Term"}},
+                        ]
+                    }
+                }
+            }
+        }
+        results = search(query=query, limit=batch_size, fields=["@id", "name"])
+        for term in results:
+            result[term.get('name')] = term.get('@id')
+    missing_names = unique_names_set - set(result.keys())
+    if len(missing_names):
+        raise Exception(f"Failed to find ids for names: {'; '.join(missing_names)}")
+    return result
